@@ -25,7 +25,7 @@ def get_payload(model_name: str, key: str):
     return _get_def(_registered_payloads, model_name, key)
 
 
-def register(model_name: str, model: Type['db.types.Model']):
+def register(model_name: str, model: Type['db.defs.Model']):
     def create_defs(collection, params):
         if params is None:
             return
