@@ -17,5 +17,5 @@ def init_services():
     for name, service in _registered_services.items():
         if isinstance(service, services.BaseService):
             service.model = db.models.get(name)
-            if issubclass(service.model, db.types.Model):
+            if issubclass(service.model, db.defs.Model):
                 mapping.register(name, service.model)
